﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:lx="http://www.landxml.org/schema/LandXML-1.0" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:landUtils="http://www.autodesk.com/land/civil/vcedit" xmlns:earthworkUtils="urn:schemas-earth" xmlns:lxml="urn:lx_utils">
	<!--Description:Earthwork volumes report-->
	<!--CreatedBy:Autodesk Inc. -->
	<!--DateCreated:04/20/2004 -->
	<!--LastModifiedBy:Autodesk Inc. -->
	<!--DateModified:04/20/2004 -->
	<!--OutputExtension:html -->
	<xsl:output method="html" encoding="UTF-8"/>
	<!-- ==== JavaScript Includes ==== -->
	<xsl:include href="../scripts/NumberFormatting.xsl"/>
	<xsl:include href="../scripts/StationFormatting.xsl"/>	
	<!-- ============================= -->
	<xsl:param name="SourceAreaUnit" select="AeccEarthworkXML/Settings/Area/@unit"/>
	<xsl:param name="SourceVolumeUnit" select="AeccEarthworkXML/Settings/Volume/@unit"/>
	<xsl:param name="Surface.2D_Area.unit">default</xsl:param>
	<xsl:param name="Surface.2D_Area.precision">0.00</xsl:param>
	<xsl:param name="Surface.2D_Area.rounding">normal</xsl:param>
	<xsl:param name="Earthwork.Volume.unit">default</xsl:param>
	<xsl:param name="Earthwork.Volume.precision">0.00</xsl:param>
	<xsl:param name="Earthwork.Volume.rounding">normal</xsl:param>
	<xsl:template match="/">
		<html>
			<head>
				<title>Výkaz zemních prací <xsl:value-of select="//lx:Alignment/@name"/>
				</title>
			</head>
			<body>
				<div style="width:7in">
					<h1 align="center">Výkaz materiálu</h1>
					<table border="0" cellspacing="0" cellpadding="0">
						<tr>
							<td>
								<h3>
									Projekt:&#160;&#160;<xsl:value-of select="AeccEarthworkXML/Project/@name"/>
								</h3>
							</td>
						</tr>
						<tr>
							<td>Zarovnání:&#160;&#160;<xsl:value-of select=".//Alignment/@name"/>
							</td>
						</tr>
						<tr>
							<td>Skupina Vzorové čáry:&#160;&#160;<xsl:value-of select=".//Alignment/CrossSects/@name"/>
							</td>
						</tr>
						<tr>
							<xsl:variable name="stationStart" select=".//Alignment/CrossSects/@startStaEq"/>
							<td>Počáteční sta:&#160;&#160;<xsl:value-of select="landUtils:getFormattedStation(string($stationStart))"/></td>
						</tr>
						<tr>
							<xsl:variable name="stationEnd" select=".//Alignment/CrossSects/@endStaEq"/>
							<td>Koncové sta:&#160;&#160;<xsl:value-of select="landUtils:getFormattedStation(string($stationEnd))"/></td>
						</tr>
					</table>
					<br/>
					<table bordercolor="black" border="1" cellspacing="0" cellpadding="3" width="98%" align="center">
						<tr style="font-size:12pt;font-family:Verdana">
							<th/>
							<th>Typ plochy</th>
							<th>Plocha</th>
							<th>Přír.obj.</th>
							<th>Kum.obj.</th>
						</tr>
						<tr>
							<th/>
							<th/>
							<xsl:choose>
								<xsl:when test="$Surface.2D_Area.unit='default'">
									<xsl:choose>
										<xsl:when test="$SourceAreaUnit='square foot'">
											<th>ft čtv.</th>
										</xsl:when>
										<xsl:when test="$SourceAreaUnit='square meter'">
											<th>m čtv.</th>
										</xsl:when>
									</xsl:choose>
								</xsl:when>
								<xsl:when test="$Surface.2D_Area.unit='square foot'">
									<th>ft čtv.</th>
								</xsl:when>
								<xsl:when test="$Surface.2D_Area.unit='square meter'">
									<th>m čtv.</th>
								</xsl:when>
							</xsl:choose>
							<xsl:choose>
								<xsl:when test="$Earthwork.Volume.unit='default'">
									<xsl:choose>
										<xsl:when test="$SourceVolumeUnit='cubic foot'">
											<th>ft kr.</th>
										</xsl:when>
										<xsl:when test="$SourceVolumeUnit='cubic meter'">
											<th>m kr.</th>
										</xsl:when>
										<xsl:when test="$SourceVolumeUnit='cubic yard'">
											<th>yd kr.</th>
										</xsl:when>
									</xsl:choose>
								</xsl:when>
								<xsl:when test="$Earthwork.Volume.unit='cubic foot'">
									<th>ft kr.</th>
								</xsl:when>
								<xsl:when test="$Earthwork.Volume.unit='cubic meter'">
									<th>m kr.</th>
								</xsl:when>
								<xsl:when test="$Earthwork.Volume.unit='cubic yard'">
									<th>yd kr.</th>
								</xsl:when>
							</xsl:choose>
							<xsl:choose>
								<xsl:when test="$Earthwork.Volume.unit='default'">
									<xsl:choose>
										<xsl:when test="$SourceVolumeUnit='cubic foot'">
											<th>ft kr.</th>
										</xsl:when>
										<xsl:when test="$SourceVolumeUnit='cubic meter'">
											<th>m kr.</th>
										</xsl:when>
										<xsl:when test="$SourceVolumeUnit='cubic yard'">
											<th>yd kr.</th>
										</xsl:when>
									</xsl:choose>
								</xsl:when>
								<xsl:when test="$Earthwork.Volume.unit='cubic foot'">
									<th>ft kr.</th>
								</xsl:when>
								<xsl:when test="$Earthwork.Volume.unit='cubic meter'">
									<th>m kr.</th>
								</xsl:when>
								<xsl:when test="$Earthwork.Volume.unit='cubic yard'">
									<th>yd kr.</th>
								</xsl:when>
							</xsl:choose>
						</tr>
						<xsl:for-each select="AeccEarthworkXML">
							<xsl:for-each select="//Alignment/CrossSects">
								<xsl:for-each select="./CrossSect">
									<tr style="font-size:10pt;font-family:Verdana">
										<xsl:variable name="station" select="@staEq"/>
										<td align="right">Staničení: 
											<xsl:value-of select="landUtils:getFormattedStation(string($station))"/>
										</td>
									</tr>
									<xsl:variable name="areaCut" select="@areaCut"/>
									<xsl:variable name="areaFill" select="@areaFill"/>
									<xsl:variable name="areaUsable" select="@areaUsable"/>
									<xsl:variable name="incVolCut" select="@volumeCut"/>
									<xsl:variable name="incVolFill" select="@volumeFill"/>
									<xsl:variable name="incVolUsable" select="@volumeUsable"/>
									<xsl:variable name="cumVolCut" select="@cumVolumeCut"/>
									<xsl:variable name="cumVolFill" select="@cumVolumeFill"/>
									<xsl:variable name="cumVolUsable" select="@cumVolumeUsable"/>
									<xsl:variable name="massHaul" select="@massHaul"/>
									<xsl:for-each select="./MaterialCrossSects/MaterialCrossSect">
										<xsl:variable name="Area" select="@area"/>
										<xsl:variable name="IncVol" select="@volume"/>
										<xsl:variable name="cumVol" select="@cumVolume"/>
										<tr style="font-size:10pt;font-family:Verdana">
											<td/>
											<td align="left">
												<xsl:value-of select="@name"/>
											</td>
											<td align="left">
												<xsl:value-of select="landUtils:FormatNumber(string($Area), string($SourceAreaUnit), string($Surface.2D_Area.unit), string($Surface.2D_Area.precision), string($Surface.2D_Area.rounding))"/>
											</td>
											<xsl:choose>
												<xsl:when test="@volume">
													<td align="left">
														<xsl:value-of select="landUtils:FormatNumber(string($IncVol), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"/>
													</td>
												</xsl:when>
												<xsl:otherwise>
													<td>Není k dispozici</td>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:choose>
												<xsl:when test="@cumVolume">
													<td align="left">
														<xsl:value-of select="landUtils:FormatNumber(string($cumVol), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"/>
													</td>
												</xsl:when>
												<xsl:otherwise>
													<td>Není k dispozici</td>
												</xsl:otherwise>
											</xsl:choose>
										</tr>
									</xsl:for-each>
								</xsl:for-each>
							</xsl:for-each>
						</xsl:for-each>
					</table>
				</div>
			</body>
		</html>
	</xsl:template>
	<msxsl:script language="vbScript" implements-prefix="earthworkUtils"><![CDATA[
function FormatVolume(numberStr, fromStr, toStr, precisionStr, roundingStr)

	dim numStr,fStr,tStr,pStr,rStr,origNumber,convNumber,precDepth,fixedDec,rNumber
	fStr = fromStr
	tStr = toStr
	pStr = precisionStr
	rStr = roundingStr
	
	numStr = numberStr


	origNumber = numStr
	
	convNumber = 0
	rNumber = numberStr
	
	' Do conversion if necessary
	if  (tStr = "default") then
		convNumber = origNumber
	else
		convNumber = ConvertVolume(origNumber, fStr, tStr)
	end if
	rNumber = FormatPrecision(convNumber, pStr, rStr)
	
	FormatVolume = CStr(rNumber)

end function

function ConvertVolume(num, fromStr, toStr)

	dim convNumber 
	dim numer 

	convNumber = num
	numer = num

	if(fromStr = "cubicFeet") then
		if(toStr = "cubicMeter") then
			convNumber = CubicFeetToMeters(numer)
		end if
	
	elseif(fromStr = "cubicMeter") then
		if(toStr = "cubicFeet") then
		
			convNumber = CubicMeterToFeet(numer)
		end if
	else
		convNumber = numer
	end if
	
	ConvertVolume = convNumber
end function


function CubicMeterToFeet(d)

	CubicMeterToFeet = d/(.3048^3)
end function

function CubicFeetToMeters(d)

	CubicFeetToMeters =  d * (.3048^3)
end function



]]></msxsl:script>
</xsl:stylesheet>

