<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:lx="http://www.landxml.org/schema/LandXML-1.1" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:landUtils="http://www.autodesk.com/land/civil/vcedit" xmlns:earthworkUtils="urn:schemas-earth" xmlns:lxml="urn:lx_utils">
	<!--Description:Earthwork volumes report-->
	<!--CreatedBy:Autodesk Inc. -->
	<!--DateCreated:04/20/2004 -->
	<!--LastModifiedBy:Autodesk Inc. -->
	<!--DateModified:04/20/2004 -->
	<!--OutputExtension:html -->
	<xsl:output method="html" encoding="UTF-8"></xsl:output>
	<!-- ==== JavaScript Includes ==== -->
	<xsl:include href="../scripts/NumberFormatting.xsl"></xsl:include>
	<xsl:include href="../scripts/StationFormatting.xsl"></xsl:include>
	<!-- ============================= -->
	<!--<xsl:param name="SourceAreaUnit" select=".//Units/*/@areaUnit"/>
	<xsl:param name="SourceVolumeUnit" select="AeccEarthworkXML/Units/*/@volumeUnit"/>
	<xsl:param name="Surface.2D_Area.unit">default</xsl:param>
	<xsl:param name="Surface.2D_Area.precision">0.00</xsl:param>
	<xsl:param name="Surface.2D_Area.rounding">normal</xsl:param>
	<xsl:param name="Earthwork.Volume.unit">default</xsl:param>
	<xsl:param name="Earthwork.Volume.precision">0.00</xsl:param>
	<xsl:param name="Earthwork.Volume.rounding">normal</xsl:param>
	<xsl:param name="projectName" select="AeccEarthworkXML/Project/@name"/>-->

	<xsl:param name="SourceAreaUnit" select="AeccEarthworkXML/Settings/Area/@unit"></xsl:param>
	<xsl:param name="SourceVolumeUnit" select="AeccEarthworkXML/Settings/Volume/@unit"></xsl:param>
	<xsl:param name="Surface.2D_Area.unit">default</xsl:param>
	<xsl:param name="Surface.2D_Area.precision">0.00</xsl:param>
	<xsl:param name="Surface.2D_Area.rounding">normal</xsl:param>
	<xsl:param name="Earthwork.Volume.unit">default</xsl:param>
	<xsl:param name="Earthwork.Volume.precision">0.00</xsl:param>
	<xsl:param name="Earthwork.Volume.rounding">normal</xsl:param>
	<xsl:param name="projectName" select="AeccEarthworkXML/Project/@name"></xsl:param>
	<xsl:param name="alignmentName" select="AeccEarthworkXML/Alignment/@name"></xsl:param>
	
	<xsl:template match="/">
		<html>
			<head>
				<title>Kubatury <xsl:value-of select="//lx:Alignment/@name"></xsl:value-of>
				</title>
			</head>
			<body>
				<div style="width:7in">
					<h1 align="center">KUBATURY ZEMNÍCH PRACÍ</h1>
					<table border="0" cellspacing="0" cellpadding="0">
						<tr>
							<td>
								<h3>
									Akce:  <xsl:value-of select="AeccEarthworkXML/Project/@name"></xsl:value-of>
								</h3>
							</td>
						</tr>
						<tr>
							<td>Trasa:  <xsl:value-of select=".//Alignment/@name"></xsl:value-of> <!-- Changed-->
							</td>
						</tr>
						<tr>
							<td>Skupina příčných řezů:  <xsl:value-of select=".//Alignment/CrossSects/@name"></xsl:value-of> <!-- Changed-->
							</td>
						</tr>
						<tr>
							<xsl:variable name="stationStart" select=".//Alignment/CrossSects/@startStaEq"></xsl:variable> <!-- Changed-->
							<td>Staničení ZÚ:  <xsl:value-of select="landUtils:getFormattedStation(string($stationStart))"></xsl:value-of></td>
						</tr>
						<tr>
							<xsl:variable name="stationEnd" select=".//Alignment/CrossSects/@endStaEq"></xsl:variable> <!-- Changed-->
							<td>Staničení KÚ:  <xsl:value-of select="landUtils:getFormattedStation(string($stationEnd))"></xsl:value-of></td>
						</tr>
					</table>
					<br></br>
					<table bordercolor="black" border="1" cellspacing="0" cellpadding="3" width="98%" align="center">
						<tr style="font-size:10pt;font-family:Verdana;text-decoration:underline">
							<xsl:variable name="linearUnit" select="AeccEarthworkXML/Settings/Distance/@unit"></xsl:variable> <!-- Changed-->
							<xsl:variable name="areaUnit" select="AeccEarthworkXML/Settings/Area/@unit"></xsl:variable>
							<xsl:variable name="volumeUnit" select="AeccEarthworkXML/Settings/Volume/@unit"></xsl:variable>
							<th>Staničení</th>
							<!--<th>Raw Station</th>-->
							<!--                                                   Cut Area                                   -->
							<xsl:choose>
								<xsl:when test="$areaUnit='square foot'">
									<th>Plocha výkopu (ft čtv.)</th>
								</xsl:when>
								<xsl:when test="$areaUnit='square meter'">
									<th>Plocha výkopu (m2)</th>
								</xsl:when>
								<xsl:otherwise>
									<th>Plocha výkopu</th>
								</xsl:otherwise>
							</xsl:choose>
							<!--                                                   Cut Volume                              -->
							<xsl:choose>
								<xsl:when test="$volumeUnit='cubic foot'">
									<th>Objem výkopu (ft kr.)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic meter'">
									<th>Objem výkopu (m3)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic yard'">
									<th>Objem výkopu (yd kr.)</th>
								</xsl:when>
								<xsl:otherwise>
									<th>Objem výkopu</th>
								</xsl:otherwise>
							</xsl:choose>
							<!--                                                   Reusable Volume                     -->
							<xsl:choose>
								<xsl:when test="$volumeUnit='cubic foot'">
									<th>Znovu použitelný objem (ft kr.)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic meter'">
									<th>Znovu použitelný objem (m3)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic yard'">
									<th>Znovu použitelný objem (yd kr.)</th>
								</xsl:when>
								<xsl:otherwise>
									<th>Znovu použitelný objem</th>
								</xsl:otherwise>
							</xsl:choose>
							<!--                                                   Fill Area          -->
							<xsl:choose>
								<xsl:when test="$areaUnit='square foot'">
									<th>Plocha násypu (ft čtv.)</th>
								</xsl:when>
								<xsl:when test="$areaUnit='square meter'">
									<th>Plocha násypu (m2)</th>
								</xsl:when>
								<xsl:otherwise>
									<th>Plocha násypu</th>
								</xsl:otherwise>
							</xsl:choose>
							<!--                                                   Fill Volume          -->
							<xsl:choose>
								<xsl:when test="$volumeUnit='cubic foot'">
									<th>Objem násypu (ft kr.)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic meter'">
									<th>Objem násypu (m3)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic yard'">
									<th>Objem násypu (yd kr.)</th>
								</xsl:when>
								<xsl:otherwise>
									<th>Objem násypu</th>
								</xsl:otherwise>
							</xsl:choose>
							<!--                                                   Cumulative Cut Volume          -->
							<xsl:choose>
								<xsl:when test="$volumeUnit='cubic foot'">
									<th>Kum. obj. výkopu (ft kr.)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic meter'">
									<th>Součet objemů vykopu (m3)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic yard'">
									<th>Kum. obj. výkopu (yd kr.)</th>
								</xsl:when>
								<xsl:otherwise>
									<th>Kum. obj. výkopu</th>
								</xsl:otherwise>
							</xsl:choose>
							<!--                                                   Cumulative Reusable Volume          -->
							<xsl:choose>
								<xsl:when test="$volumeUnit='cubic foot'">
									<th>Kum. znovu použitelný obj. (ft kr.)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic meter'">
									<th>Kum. znovu použitelný obj.(m3)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic yard'">
									<th>Kum. znovu použitelný obj. (yd kr.)</th>
								</xsl:when>
								<xsl:otherwise>
									<th>Kum. znovu použitelný obj.</th>
								</xsl:otherwise>
							</xsl:choose>
							<!--                                                   Cumulative Fill Volume          -->
							<xsl:choose>
								<xsl:when test="$volumeUnit='cubic foot'">
									<th>Kum. obj. násypu (ft kr.)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic meter'">
									<th>Součet objemů násypu (m3)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic yard'">
									<th>Kum. obj. násypu (yd kr.)</th>
								</xsl:when>
								<xsl:otherwise>
									<th>Kum. obj. násypu</th>
								</xsl:otherwise>
							</xsl:choose>
							<!--<th>Net Volume</th>-->
							<!--                                                   Cumulative Net Volume          -->
							<xsl:choose>
								<xsl:when test="$volumeUnit='cubic foot'">
									<th>Kum. čistý obj. (ft kr.)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic meter'">
									<th>Hmotnice (m3)</th>
								</xsl:when>
								<xsl:when test="$volumeUnit='cubic yard'">
									<th>Kum. čistý obj. (yd kr.)</th>
								</xsl:when>
								<xsl:otherwise>
									<th>Kum. čistý obj.</th>
								</xsl:otherwise>
							</xsl:choose>
							<th></th>
							<!-- extra cell at the end is indroduced-->
						</tr>
						<tr>
							<!-- Introduces a small gap between header and the data-->
						</tr>
						<!--     Following section presents earthwork data in tabular form-->
						<xsl:for-each select="AeccEarthworkXML">
							<xsl:for-each select="//Alignment/CrossSects">
								<xsl:for-each select="./CrossSect">
									<tr style="font-size:10pt;font-family:Verdana">
										<xsl:variable name="station" select="@staEq"></xsl:variable>
										<td align="right">
											<xsl:value-of select="landUtils:getFormattedStation(string($station))"></xsl:value-of>
										</td>
										<xsl:variable name="areaCut" select="@areaCut"></xsl:variable>
										<xsl:variable name="areaFill" select="@areaFill"></xsl:variable>
										<xsl:variable name="areaUsable" select="@areaUsable"></xsl:variable>
										<xsl:variable name="incVolCut" select="@volumeCut"></xsl:variable>
										<xsl:variable name="incVolFill" select="@volumeFill"></xsl:variable>
										<xsl:variable name="incVolUsable" select="@volumeUsable"></xsl:variable>
										<xsl:variable name="cumVolCut" select="@cumVolumeCut"></xsl:variable>
										<xsl:variable name="cumVolFill" select="@cumVolumeFill"></xsl:variable>
										<xsl:variable name="cumVolUsable" select="@cumVolumeUsable"></xsl:variable>
										<xsl:variable name="massHaul" select="@massHaul"></xsl:variable>
										<!--                                                   Cut Area                                   -->
										<xsl:choose>
											<xsl:when test="@areaCut">
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string($areaCut), string($SourceAreaUnit), string($Surface.2D_Area.unit), string($Surface.2D_Area.precision), string($Surface.2D_Area.rounding))"></xsl:value-of>
												</td>
											</xsl:when>
											<xsl:otherwise>
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string(0.0), string($SourceAreaUnit), string($Surface.2D_Area.unit), string($Surface.2D_Area.precision), string($Surface.2D_Area.rounding))"></xsl:value-of>
												</td>
											</xsl:otherwise>
										</xsl:choose>
										<!--                                                   Cut Volume                                   -->
										<xsl:choose>
											<xsl:when test="@volumeCut">
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string($incVolCut), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:when>
											<xsl:otherwise>
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string(0.0), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:otherwise>
										</xsl:choose>
										<!--                                                   Reusable Volume                                   -->
										<xsl:choose>
											<xsl:when test="@volumeUsable">
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string($incVolUsable), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:when>
											<xsl:otherwise>
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string(0.0), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:otherwise>
										</xsl:choose>
										<!--                                                   Fill Area                                   -->
										<xsl:choose>
											<xsl:when test="@areaFill">
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string($areaFill), string($SourceAreaUnit), string($Surface.2D_Area.unit), string($Surface.2D_Area.precision), string($Surface.2D_Area.rounding))"></xsl:value-of>
												</td>
											</xsl:when>
											<xsl:otherwise>
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string(0.0), string($SourceAreaUnit), string($Surface.2D_Area.unit), string($Surface.2D_Area.precision), string($Surface.2D_Area.rounding))"></xsl:value-of>
												</td>
											</xsl:otherwise>
										</xsl:choose>
										<!--                                                   Fill Volume                                   -->
										<xsl:choose>
											<xsl:when test="@volumeFill">
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string($incVolFill), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:when>
											<xsl:otherwise>
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string(0.0), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:otherwise>
										</xsl:choose>
										<!--                                                   Cumulativive Cut Volume                   -->
										<xsl:choose>
											<xsl:when test="@cumVolumeCut">
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string($cumVolCut), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:when>
											<xsl:otherwise>
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string(0.0), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:otherwise>
										</xsl:choose>
										<!--                                                   Cumulative Reusable Volume                 -->
										<xsl:choose>
											<xsl:when test="@cumVolumeUsable">
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string($cumVolUsable), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:when>
											<xsl:otherwise>
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string(0.0), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:otherwise>
										</xsl:choose>
										<!--                                                   Cumulative Fill Volume                                   -->
										<xsl:choose>
											<xsl:when test="@cumVolumeFill">
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string($cumVolFill), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:when>
											<xsl:otherwise>
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string(0.0), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:otherwise>
										</xsl:choose>
										<!--                                                   Cumulative Net Volume                                  -->
										<xsl:choose>
											<xsl:when test="@massHaul">
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string($massHaul), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:when>
											<xsl:otherwise>
												<td align="right">
													<xsl:value-of select="landUtils:FormatNumber(string(0.0), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))"></xsl:value-of>
												</td>
											</xsl:otherwise>
										</xsl:choose>
									</tr>
								</xsl:for-each>
							</xsl:for-each>
						</xsl:for-each>
					</table>
				</div>
			</body>
		</html>
	</xsl:template>
	<msxsl:script language="vbScript" implements-prefix="earthworkUtils"><![CDATA[
function FormatVolume(numberStr, fromStr, toStr, precisionStr, roundingStr)

	dim numStr,fStr,tStr,pStr,rStr,origNumber,convNumber,precDepth,fixedDec,rNumber
	fStr = fromStr
	tStr = toStr
	pStr = precisionStr
	rStr = roundingStr
	
	numStr = numberStr


	origNumber = numStr
	
	convNumber = 0
	rNumber = numberStr
	
	' Do conversion if necessary
	if  (tStr = "default") then
		convNumber = origNumber
	else
		convNumber = ConvertVolume(origNumber, fStr, tStr)
	end if
	rNumber = FormatPrecision(convNumber, pStr, rStr)
	
	FormatVolume = CStr(rNumber)

end function

function ConvertVolume(num, fromStr, toStr)

	dim convNumber 
	dim numer 

	convNumber = num
	numer = num

	if(fromStr = "cubicFeet") then
		if(toStr = "cubicMeter") then
			convNumber = CubicFeetToMeters(numer)
		end if
	
	elseif(fromStr = "cubicMeter") then
		if(toStr = "cubicFeet") then
		
			convNumber = CubicMeterToFeet(numer)
		end if
	else
		convNumber = numer
	end if
	
	ConvertVolume = convNumber
end function


function CubicMeterToFeet(d)

	CubicMeterToFeet = d/(.3048^3)
end function

function CubicFeetToMeters(d)

	CubicFeetToMeters =  d * (.3048^3)
end function



]]></msxsl:script>
</xsl:stylesheet>
