<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:lx="http://www.landxml.org/schema/LandXML-1.1"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:msxsl="urn:schemas-microsoft-com:xslt"
	xmlns:landUtils="http://www.autodesk.com/land/civil/vcedit"
	xmlns:lxml="urn:lx_utils">

<!--Description:Alignment Station Curve report.
This form is valid for LandXML 0.88, 1.0 and 1.1 data.
Spiral data in this report is accurate for clothoid spirals only.-->
<!--CreatedBy:Autodesk Inc. -->
<!--DateCreated:06/15/2002 -->
<!--LastModifiedBy:Autodesk Inc. -->
<!--DateModified:09/16/2002 -->
<!--OutputExtension:html -->

<xsl:output method="html" encoding="UTF-8"/>

<!-- =========== JavaScript Include==== -->
<xsl:include href="header.xsl"/>
<xsl:include href="H_Align_Layout_b.xsl"/>
<xsl:include href="Number_Formatting.xsl"/>
<!-- ================================= -->

<xsl:param name="SourceLinearUnit" select="//lx:Units/*/@linearUnit"/>

<xsl:template match="/">

<html>
<head>
	<title>Horizontal Alignment Station and Curve Report</title>
</head>
<body>
<div style="width:7in">

<xsl:call-template name="AutoHeader">
<xsl:with-param name="ReportTitle">Hlavni body trasy</xsl:with-param>
<xsl:with-param name="ReportDesc"><xsl:value-of select="//lx:Project/@name"/></xsl:with-param>
</xsl:call-template>

<xsl:apply-templates select="//lx:Alignment"/>
</div>
</body>
</html>
</xsl:template>

<xsl:template match="lx:Alignment">
	<h3>Nazev trasy: <xsl:value-of select="@name"/></h3>
	<hr color = "black"/>
	
	<!-- Load and set stationing for the alignment geometry -->
	<!-- Loads the geometry -->
	<xsl:apply-templates select="./lx:CoordGeom" mode="set"></xsl:apply-templates>
	
	<!-- Sets the internal stationing of the geometry -->
 	<xsl:variable name="AppStations" select="landUtils:ApplyStationing(@staStart)"/>
	
	<!-- Load the station Equations -->
	<xsl:if test="./lx:StaEquation">	
		<h3>Station Equations</h3>
		<table border="2" width="100%">
			<tbody>
				<tr bgcolor="#eeeeee">
					<th>Internal Station</th>
					<th>Back Station</th>
					<th>Ahead Station</th>
				</tr>

			<xsl:for-each select="./lx:StaEquation">
				<tr>
					<td><xsl:value-of select="@staInternal"/></td>
					<td><xsl:value-of select="@staBack"/></td>
					<td><xsl:value-of select="@staAhead"/></td>
				</tr>
				<xsl:variable name="loadStaEquation" select="landUtils:AddStationEquation(string(@staInternal), string(@staBack), string(@staAhead))"/>	
			</xsl:for-each>
		</tbody>
	</table>
	<p></p>
	</xsl:if>
	
	<!-- Apply the station equations to the alignment geometry -->
 	<xsl:variable name="appstaeq" select="landUtils:ApplyStationEquations()"/>
	
	<!-- Begin iteration of the geometry -->
	<xsl:apply-templates select="./lx:CoordGeom"></xsl:apply-templates> 

</xsl:template>

<xsl:template match="lx:CoordGeom">
<table width="100%">
	<xsl:for-each select="./node()">
		<xsl:variable name="pos" select="position()"/>
		<xsl:variable name="prev" select="position()-1"/>
		<xsl:variable name="next" select="position()+1"/>
		<xsl:variable name="startStation" select="landUtils:GetGeomStartingStation($pos)"/>
		<xsl:variable name="endStation" select="landUtils:GetGeomEndStation($pos)"/>
		<xsl:variable name="Bearing">Bearing</xsl:variable>
		<xsl:variable name="Conventional">Conventional</xsl:variable>

		<xsl:choose>
			<xsl:when test="name()='Line'">
				
				<tr>
					<td colspan="4" align="left"><hr color = "#ddddff" size="4"/><u>Prima cast</u></td>
				</tr>
				<tr  bgcolor="eeeeee">
						<th align="left">Bod</th>
						<th align="left">Staniceni</th>
						<th align="left">souradnice Y</th>
						<th align="left">souradnice X</th>
				</tr>	

				<xsl:variable name="PrevElement" select="landUtils:GetGeomElementType($prev)"/>
				<xsl:variable name="NextElement" select="landUtils:GetGeomElementType($next)"/>
									
				<tr>
					<xsl:choose>
						<xsl:when test="string($PrevElement) = 'Spiral'">
							<td>PT:</td>
						</xsl:when>
						<xsl:when test="string($PrevElement) = 'Curve'">
							<td>KT:</td>
						</xsl:when>
						<xsl:otherwise>
							<td>ZU:</td>
						</xsl:otherwise>
					</xsl:choose>
					
					<td><xsl:value-of select="landUtils:FormatStation(string($startStation), string($Alignment.Station.Display), string($Alignment.Station.precision), string($Alignment.Station.rounding))"/></td>
					<xsl:variable name="startE" select="landUtils:GetLineStartEasting($pos)"/>
					<xsl:variable name="startN" select="landUtils:GetLineStartNorthing($pos)"/>
					<td><xsl:value-of select="landUtils:FormatNumber(string($startE), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string($Alignment.Coordinate.rounding))"/></td>
					<td><xsl:value-of select="landUtils:FormatNumber(string($startN), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string($Alignment.Coordinate.rounding))"/></td>				
				</tr>				

				<tr>
					<xsl:choose>
						<xsl:when test="string($NextElement) = 'Spiral'">
							<td>TP:</td>
						</xsl:when>
						<xsl:when test="string($NextElement) = 'Curve'">
							<td>TK:</td>
						</xsl:when>
						<xsl:otherwise>
							<td>KU:</td>
						</xsl:otherwise>
					</xsl:choose>
									
					<td><xsl:value-of select="landUtils:FormatStation(string($endStation), string($Alignment.Station.Display), string($Alignment.Station.precision), string($Alignment.Station.rounding))"/></td>
					<xsl:variable name="endE" select="landUtils:GetLineEndEasting($pos)"/>
					<xsl:variable name="endN" select="landUtils:GetLineEndNorthing($pos)"/>
					<td><xsl:value-of select="landUtils:FormatNumber(string($endE), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string($Alignment.Coordinate.rounding))"/></td>
					<td><xsl:value-of select="landUtils:FormatNumber(string($endN), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string($Alignment.Coordinate.rounding))"/></td>				
				</tr>								
			</xsl:when>

		<xsl:when test="name()='Curve'">		
				<tr>
					<td colspan="4" align="left"><hr color = "#ddddff" size="4"/><u>Oblouk</u></td>
				</tr>
				<tr  bgcolor="eeeeee">
					<th align="left">Bod</th>
					<th align="left">Staniceni</th>
					<th align="left">souradnice Y</th>
					<th align="left">souradnice X</th>
				</tr>
				
				<xsl:variable name="PrevElement" select="landUtils:GetGeomElementType($prev)"/>
				<xsl:variable name="NextElement" select="landUtils:GetGeomElementType($next)"/>
									
				<tr>
					<xsl:choose>
						<xsl:when test="string($PrevElement) = 'Line'">
							<td>TK:</td>
						</xsl:when>
						<xsl:when test="string($PrevElement) = 'Spiral'">
							<td>PK:</td>
						</xsl:when>
						<xsl:when test="string($PrevElement) = 'Curve'">
							<td>KK:</td>
						</xsl:when>
						<xsl:otherwise>
							<td>ZU:</td>
						</xsl:otherwise>
					</xsl:choose>
					
					<td><xsl:value-of select="landUtils:FormatStation(string($startStation), string($Alignment.Station.Display), string($Alignment.Station.precision), string($Alignment.Station.rounding))"/></td>
					<xsl:variable name="sEast" select="landUtils:GetCurveStartEasting($pos)"/>
					<td><xsl:value-of select="landUtils:FormatNumber(string($sEast), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string($Alignment.Coordinate.rounding))"/></td>
					<xsl:variable name="sNorth" select="landUtils:GetCurveStartNorthing($pos)"/>
					<td><xsl:value-of select="landUtils:FormatNumber(string($sNorth), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string($Alignment.Coordinate.rounding))"/></td>
				</tr>
				
				<tr>
					<xsl:choose>
						<xsl:when test="string($NextElement) = 'Line'">
							<td>KT:</td>
						</xsl:when>
						<xsl:when test="string($NextElement) = 'Spiral'">
							<td>KP:</td>
						</xsl:when>
						<xsl:when test="string($NextElement) = 'Curve'">
							<td>KK:</td>
						</xsl:when>
						<xsl:otherwise>
							<td>KU:</td>
						</xsl:otherwise>
					</xsl:choose>
				
					<td><xsl:value-of select="landUtils:FormatStation(string($endStation), string($Alignment.Station.Display), string($Alignment.Station.precision), string($Alignment.Station.rounding))"/></td>
					<xsl:variable name="eEast" select="landUtils:GetCurveEndEasting($pos)"/>
					<td><xsl:value-of select="landUtils:FormatNumber(string($eEast), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string($Alignment.Coordinate.rounding))"/></td>
					<xsl:variable name="eNorth" select="landUtils:GetCurveEndNorthing($pos)"/>
					<td><xsl:value-of select="landUtils:FormatNumber(string($eNorth), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string($Alignment.Coordinate.rounding))"/></td>
				</tr>
			</xsl:when>
												
						
			<xsl:when test="name()='Spiral'">		
				<xsl:variable name="SpiralType" select="landUtils:GetSpiralType($pos)"/>	
						
				<tr>
					<td colspan="4" align="left"><hr color = "#ddddff" size="4"/><u>Prechodnice</u></td>
				</tr>
				<tr  bgcolor="eeeeee">
					<th align="left">Bod</th>
					<th align="left">Staniceni</th>
					<th align="left">souradnice Y</th>
					<th align="left">souradnice X</th>
				</tr>
				
				<xsl:variable name="PrevElement" select="landUtils:GetGeomElementType($prev)"/>
				<xsl:variable name="NextElement" select="landUtils:GetGeomElementType($next)"/>
								
				<tr>
					<xsl:choose>
						<xsl:when test="string($PrevElement) = 'Line'">
							<td>TP:</td>
						</xsl:when>
						<xsl:when test="string($PrevElement) = 'Curve'">
							<td>KP:</td>
						</xsl:when>
						<xsl:when test="string($PrevElement) = 'Spiral'">
							<td>PP:</td>
						</xsl:when>
						<xsl:otherwise>
							<td>ZU:</td>
						</xsl:otherwise>
					</xsl:choose>							
				
					<td><xsl:value-of select="landUtils:FormatStation(string($startStation), string($Alignment.Station.Display), string($Alignment.Station.precision), string($Alignment.Station.rounding))"/></td>
					<xsl:variable name="sse" select="landUtils:GetSpiralStartEasting($pos)"/>
					<td><xsl:value-of select="landUtils:FormatNumber(string($sse), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string	($Alignment.Coordinate.rounding))"/></td>
					<xsl:variable name="ssn" select="landUtils:GetSpiralStartNorthing($pos)"/>
					<td><xsl:value-of select="landUtils:FormatNumber(string($ssn), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string	($Alignment.Coordinate.rounding))"/></td>
				</tr>
													
				<tr>
					<xsl:choose>
						<xsl:when test="string($NextElement) = 'Line'">
							<td>PT:</td>
						</xsl:when>
						<xsl:when test="string($NextElement) = 'Curve'">
							<td>PK:</td>
						</xsl:when>
						<xsl:when test="string($NextElement) = 'Spiral'">
							<td>PP:</td>
						</xsl:when>
						<xsl:otherwise>
							<td>KU:</td>
						</xsl:otherwise>
					</xsl:choose>
				
					<td><xsl:value-of select="landUtils:FormatStation(string($endStation), string($Alignment.Station.Display), string($Alignment.Station.precision), string($Alignment.Station.rounding))"/></td>
					<xsl:variable name="see" select="landUtils:GetSpiralEndEasting($pos)"/>
					<td><xsl:value-of select="landUtils:FormatNumber(string($see), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string	($Alignment.Coordinate.rounding))"/></td>
					<xsl:variable name="sen" select="landUtils:GetSpiralEndNorthing($pos)"/>
					<td><xsl:value-of select="landUtils:FormatNumber(string($sen), string($SourceLinearUnit), string($Alignment.Coordinate.unit), string($Alignment.Coordinate.precision), string	($Alignment.Coordinate.rounding))"/></td>
				</tr>
				
				<xsl:choose> 
					<xsl:when test="$SpiralType!='clothoid'">
						<tr>
							<td colspan="4" align="left"><u>Spiral Curve: <xsl:value-of select="landUtils:GetSpiralType($pos)"/></u></td>
						</tr>
						<tr>
							<td colspan="3">Values not reported for non-clothoid spirals</td>
						</tr>
					</xsl:when>
				<xsl:otherwise>
				
				</xsl:otherwise>
			</xsl:choose> <!--End test for spiral type-->

						
		</xsl:when>	
			<xsl:otherwise><tr></tr></xsl:otherwise>
		</xsl:choose> <!--End test for element type-->
		
	</xsl:for-each>
	</table>
	<hr color = "black"/>
</xsl:template>

</xsl:stylesheet>