<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:lxml="urn:lx_utils"
                xmlns:lx="http://www.landxml.org/schema/LandXML-1.1"
                xmlns:landUtils="http://www.autodesk.com/land/civil/vcedit">
  <!--Description:Metes and Bounds report.
This form is valid for LandXML 0.88, 1.0 and 1.1 data.-->

  <!--CreatedBy:Autodesk Inc. -->

  <!--DateCreated:06/15/2002 -->

  <!--LastModifiedBy:Autodesk Inc. -->

  <!--DateModified:10/9/2002 -->

  <!--OutputExtension:html -->

  <xsl:output encoding="UTF-8" method="html" />

  <!-- =========== JavaScript Includes ==== -->

  <xsl:include href="LandXMLUtils_JScript.xsl" />

  <xsl:include href="General_Formating_JScript.xsl" />

  <xsl:include href="Plan_Comp_JScript.xsl" />

  <xsl:include href="Conversion_JScript.xsl" />

  <xsl:include href="Number_Formatting.xsl" />

  <xsl:include href="Parcel_Layout.xsl" />

  <xsl:include href="header.xsl" />

  <xsl:param name="SourceLinearUnit" select="//lx:Units/*/@linearUnit" />

  <xsl:template match="/">
    <html>
      <head>
        <title>Výpis oměrných pro parcely<xsl:value-of
        select="//lx:Project/@name" /></title>
      </head>

      <body>
        <div style="width:7in">
          <xsl:call-template name="AutoHeader">
            <xsl:with-param name="ReportTitle">Výpis oměrných pro
            parcely</xsl:with-param>

            <xsl:with-param name="ReportDesc">
              <xsl:value-of select="//lx:Project/@name" />
            </xsl:with-param>
          </xsl:call-template>

          <xsl:apply-templates select="//lx:Parcel" />
        </div>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="lx:Parcel"> <xsl:apply-templates mode="set"
  select="." /> <h2>Popis oměrných pro parcely<xsl:value-of
  select="landUtils:FormatCase(string(@name), $Parcel.Name.capitalization)" /></h2>
  <xsl:apply-templates select="./lx:CoordGeom" /> do počátečního
  bodu.<br /><br /><hr /> </xsl:template>

  <xsl:template match="lx:CoordGeom"> <xsl:variable name="ComNorthing"
  select="landUtils:GetCommencePointNorthing()" /> <xsl:variable
  name="ComEasting" select="landUtils:GetCommencePointEasting()" /> Počáteční
  bod má souřadnici X <xsl:value-of
  select="landUtils:FormatNumber(string($ComNorthing), string($SourceLinearUnit), string($Parcel.Point_Coordinates.unit), string($Parcel.Point_Coordinates.precision), string($Parcel.Point_Coordinates.rounding))" />a
  souřadnici Y<xsl:value-of
  select="landUtils:FormatNumber(string($ComEasting), string($SourceLinearUnit), string($Parcel.Point_Coordinates.unit), string($Parcel.Point_Coordinates.precision), string($Parcel.Point_Coordinates.rounding))" />
  <xsl:for-each select="./node()">
      <xsl:apply-templates select="." />
    </xsl:for-each> </xsl:template>

  <xsl:template match="lx:Line"> <xsl:apply-templates mode="set" select="." />
  <xsl:variable name="angle" select="landUtils:GetLineAngle()" />
  <xsl:variable name="LineLength" select="landUtils:GetLineLength()" />
  ;<br />směrník<xsl:value-of select="landUtils:formatBearingDMS($angle)" />
  vzdálenost<xsl:value-of
  select="landUtils:FormatNumber(string($LineLength), string($SourceLinearUnit), string($Parcel.Line_Segment_Length.unit), string($Parcel.Line_Segment_Length.precision), string($Parcel.Line_Segment_Length.rounding))" />&#160;
  <xsl:choose>
      <xsl:when test="$Parcel.Line_Segment_Length.unit='default'">
        <xsl:choose>
          <xsl:when test="$SourceLinearUnit='foot'">feet</xsl:when>

          <xsl:when test="$SourceLinearUnit='meter'">metrů</xsl:when>
        </xsl:choose>
      </xsl:when>

      <xsl:when test="$Parcel.Line_Segment_Length.unit='foot'">feet</xsl:when>

      <xsl:when
      test="$Parcel.Line_Segment_Length.unit='meter'">metrů</xsl:when>
    </xsl:choose> </xsl:template>

  <xsl:template match="lx:Curve"> <xsl:apply-templates mode="set"
  select="." /> <xsl:variable name="CurveAngle"
  select="landUtils:GetCurveAngle()" /> <xsl:variable name="CurveRadius"
  select="landUtils:GetCurveRadius()" /> <xsl:variable name="ChordDir"
  select="landUtils:CalculateBearingDMS(./lx:Start,./lx:End)" /> <xsl:variable
  name="ChordLength" select="landUtils:GetChordLength()" /> ;<br />podél
  křivky<xsl:value-of select="landUtils:GetCurveDirection()" />má
  poloměr<xsl:value-of
  select="landUtils:FormatNumber(string($CurveRadius), string($SourceLinearUnit), string($Parcel.Curve_Segment_Radius.unit), string($Parcel.Curve_Segment_Radius.precision), string($Parcel.Curve_Segment_Radius.rounding))" />&#160;
  <xsl:choose>
      <xsl:when test="$Parcel.Curve_Segment_Radius.unit='default'">
        <xsl:choose>
          <xsl:when test="$SourceLinearUnit='foot'">feet,</xsl:when>

          <xsl:when test="$SourceLinearUnit='meter'">metrů</xsl:when>
        </xsl:choose>
      </xsl:when>

      <xsl:when
      test="$Parcel.Curve_Segment_Radius.unit='foot'">feet,</xsl:when>

      <xsl:when
      test="$Parcel.Curve_Segment_Radius.unit='meter'">metrů,</xsl:when>
    </xsl:choose>středový úhel<xsl:value-of
  select="landUtils:FormatNumber(string($CurveAngle), string('default'), string($Parcel.Curve_Segment_Radius.unit), string($Parcel.Curve_Segment_Delta_Angle.precision), string($Parcel.Curve_Segment_Delta_Angle.rounding))" />jehož
  délka tětivy<xsl:value-of select="$ChordDir" />vzdálenost<xsl:value-of
  select="landUtils:FormatNumber(string($ChordLength), string($SourceLinearUnit), string($Parcel.Curve_Segment_Chord_Length.unit), string($Parcel.Curve_Segment_Chord_Length.precision), string($Parcel.Curve_Segment_Chord_Length.rounding))" />&#160;
  <xsl:choose>
      <xsl:when test="$Parcel.Curve_Segment_Chord_Length.unit='default'">
        <xsl:choose>
          <xsl:when test="$SourceLinearUnit='foot'">feet</xsl:when>

          <xsl:when test="$SourceLinearUnit='meter'">metrů</xsl:when>
        </xsl:choose>
      </xsl:when>

      <xsl:when
      test="$Parcel.Curve_Segment_Chord_Length.unit='foot'">feet</xsl:when>

      <xsl:when
      test="$Parcel.Curve_Segment_Chord_Length.unit='meter'">metrů</xsl:when>
    </xsl:choose> </xsl:template>
</xsl:stylesheet>