<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:lxml="urn:lx_utils"
                xmlns:lx="http://www.landxml.org/schema/LandXML-1.1"
                xmlns:landUtils="http://www.autodesk.com/land/civil/vcedit">
  <xsl:output encoding="UTF-8" method="html" />

  <!--Description:SurfaceReport.
This form is valid for LandXML 0.88, 1.0 and 1.1 data.-->

  <!--CreatedBy:Autodesk Inc. -->

  <!--DateCreated:06/15/2002 -->

  <!--LastModifiedBy:Autodesk Inc. -->

  <!--DateModified:01/16/2006 -->

  <!--OutputExtension:html -->

  <!-- =========== JavaScript Include==== -->

  <xsl:include href="LandXMLUtils_JScript.xsl" />

  <xsl:include href="Surface_Layout.xsl" />

  <xsl:include href="General_Formating_JScript.xsl" />

  <xsl:include href="Conversion_JScript.xsl" />

  <xsl:include href="header.xsl" />

  <!-- ================================= -->

  <xsl:param name="SourceLinearUnit" select="//lx:Units/*/@linearUnit" />

  <xsl:param name="SourceAreaUnit" select="//lx:Units/*/@areaUnit" />

  <xsl:param name="SourceVolumeUnit" select="//lx:Units/*/@volumeUnit" />

  <xsl:template match="/">
    <xsl:call-template name="SetGeneralFormatParameters" />

    <html>
      <body>
        <div style="width:7in">
          <xsl:call-template name="AutoHeader">
            <xsl:with-param name="ReportTitle">Informace o
            povrchu</xsl:with-param>

            <xsl:with-param name="ReportDesc">
              <xsl:value-of select="//lx:Project/@name" />
            </xsl:with-param>
          </xsl:call-template>

          <table border="2" width="100%">
            <tr>
              <td>
                <b>Lineární jednotky: </b>

                <xsl:value-of select="//lx:Units/*/@linearUnit" />
              </td>

              <td>
                <b>Jednotky plochy: </b>

                <xsl:value-of select="//lx:Units/*/@areaUnit" />
              </td>

              <td>
                <b>Jednotky objemu: </b>

                <xsl:value-of select="//lx:Units/*/@volumeUnit" />
              </td>
            </tr>
          </table>

          <xsl:apply-templates select="//lx:Surface" />

          <xsl:apply-templates select="//lx:SurfVolume" />

          <hr color="black" />
        </div>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="//lx:Surface"> <hr color="black" /> <b>Povrch:
  <xsl:value-of select="@name" /></b><br />Popis: <xsl:value-of
  select="@desc" /> <table bgcolor="lightgreen" width="100%">
      <tr>
        <td>Plocha 2D: <xsl:value-of select="./lx:Definition/@area2DSurf" />
        </td>

        <td>Plocha 3D: <xsl:value-of select="./lx:Definition/@area3DSurf" />
        </td>
      </tr>

      <tr>
        <td>Max. výška: <xsl:value-of select="./lx:Definition/@elevMax" />
        </td>

        <td>Min. výška: <xsl:value-of select="./lx:Definition/@elevMin" />
        </td>
      </tr>

      <tr>
        <td>Počet bodů: <xsl:value-of select="count(.//lx:P)" /> </td>

        <td>Počet trojúhelníků: <xsl:value-of
        select="count(.//lx:F[not(@i)])" /> </td>
      </tr>
    </table> </xsl:template>

  <xsl:template match="//lx:SurfVolume"> <hr color="black" /> <b>Objem
  povrchu: <xsl:value-of select="@name" /></b><br />Popis: <xsl:value-of
  select="@desc" /> <table bgcolor="cyan" width="100%">
      <tr>
        <td>Objem výkopu: <xsl:value-of select="@volCut" /> </td>

        <td>Objem násypu: <xsl:value-of select="@volFill" /> </td>

        <td>Celkový objem: <xsl:value-of select="@volTotal" /> </td>
      </tr>

      <tr>
        <td>Srovnávací povrch: <xsl:value-of
        select="@surfCompare" /><br />Základní povrch: <xsl:value-of
        select="@surfBase" /> </td>
      </tr>
    </table> </xsl:template>
</xsl:stylesheet>