<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:lxml="urn:lx_utils"
                xmlns:lx="http://www.landxml.org/schema/LandXML-1.1"
                xmlns:landUtils="http://www.autodesk.com/land/civil/vcedit">
  <!--Description:Point data in comma delimited format, suitable for spreadsheet import.
This form is valid for LandXML 0.88, 1.0 and 1.1 data.-->

  <!--CreatedBy:Autodesk Inc. -->

  <!--DateCreated:06/15/2002 -->

  <!--LastModifiedBy:Autodesk Inc. -->

  <!--DateModified:09/27/2002 -->

  <!--OutputExtension:csv -->

  <xsl:output encoding="us-ascii" media-type="iso-8859-1" method="text" />

  <!-- ==== JavaScript Includes ==== -->

  <xsl:include href="LandXMLUtils_JScript.xsl" />

  <xsl:include href="General_Formating_JScript.xsl" />

  <xsl:include href="Number_Formatting.xsl" />

  <xsl:include href="Cogo_Point.xsl" />

  <!-- ============================= -->

  <xsl:param name="SourceLinearUnit" select="//lx:Units/*/@linearUnit" />

  <xsl:template match="/">
    <xsl:text>"Název bodu",</xsl:text>

    <xsl:choose>
      <xsl:when test="$Point.Coordinate.unit='default'">
        <xsl:choose>
          <xsl:when test="$SourceLinearUnit='foot'">
            <xsl:text>"X (ft)","Y (ft)",</xsl:text>
          </xsl:when>

          <xsl:when test="$SourceLinearUnit='meter'">
            <xsl:text>"X (m)","Y (m)",</xsl:text>
          </xsl:when>
        </xsl:choose>
      </xsl:when>

      <xsl:when test="$Point.Coordinate.unit='foot'">
        <xsl:text>"X (ft)","Y (ft)",</xsl:text>
      </xsl:when>

      <xsl:when test="$Point.Coordinate.unit='meter'">
        <xsl:text>"X (m)","Y (m)",</xsl:text>
      </xsl:when>
    </xsl:choose>

    <xsl:choose>
      <xsl:when test="$Point.Elevation.unit='default'">
        <xsl:choose>
          <xsl:when test="$SourceLinearUnit='foot'">
            <xsl:text>"Výška (ft)",</xsl:text>
          </xsl:when>

          <xsl:when test="$SourceLinearUnit='meter'">
            <xsl:text>"Výška (m)",</xsl:text>
          </xsl:when>
        </xsl:choose>
      </xsl:when>

      <xsl:when test="$Point.Elevation.unit='foot'">
        <xsl:text>"Výška (ft)",</xsl:text>
      </xsl:when>

      <xsl:when test="$Point.Elevation.unit='meter'">
        <xsl:text>"Výška (m)",</xsl:text>
      </xsl:when>
    </xsl:choose>

    <xsl:text>"Popis" </xsl:text>

    <xsl:call-template name="SetGeneralFormatParameters" />

    <xsl:for-each select="//lx:CgPoint[not(@pntRef)]"> <xsl:apply-templates
    mode="set" select="." /> <xsl:variable name="Northing"
    select="landUtils:GetCogoPointNorthing()" /> <xsl:variable name="Easting"
    select="landUtils:GetCogoPointEasting()" /> <xsl:variable name="Elevation"
    select="landUtils:GetCogoPointElevation()" /> <xsl:text />"<xsl:value-of
    select="@name" />",<xsl:text /> <xsl:text />"<xsl:value-of
    select="landUtils:FormatNumber(string($Northing), string($SourceLinearUnit), string($Point.Coordinate.unit), string($Point.Coordinate.precision), string($Point.Coordinate.rounding))" />",<xsl:text />
    <xsl:text />"<xsl:value-of
    select="landUtils:FormatNumber(string($Easting), string($SourceLinearUnit), string($Point.Coordinate.unit), string($Point.Coordinate.precision), string($Point.Coordinate.rounding))" />",<xsl:text />
    <xsl:text />"<xsl:value-of
    select="landUtils:FormatNumber(string($Elevation), string($SourceLinearUnit), string($Point.Elevation.unit), string($Point.Elevation.precision), string($Point.Elevation.rounding))" />",<xsl:text />
    <xsl:choose>
        <xsl:when test="@desc"> <xsl:text />"<xsl:value-of
        select="@desc" />"<xsl:text /> </xsl:when>

        <xsl:when test="@code"> <xsl:text />"<xsl:value-of
        select="@code" />"<xsl:text /> </xsl:when>

        <xsl:otherwise> <xsl:text />"NA"<xsl:text /> </xsl:otherwise>
      </xsl:choose> <xsl:text /> </xsl:for-each>
  </xsl:template>
</xsl:stylesheet>